@@ -54,7 +54,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 
 );
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 my(%_decode_xml) =
 (
@@ -423,6 +423,12 @@ sub restore_in_order
 
 			next if (! $$record{'row'});
 
+			# Warning. If the XML file contains 1 'record', XML::Records
+			# returns text or a hash ref, not an array ref containing one element.
+			# Due to the nature of our data, we can ignore the case of textual data.
+
+			$$record{'row'} = [$$record{'row'}] if (ref $$record{'row'} ne 'ARRAY');
+
 			for $row (@{$$record{'row'} })
 			{
 				# There may be a different number of fields from one row to the next.
